usr/src/uts/common/fs/namefs/namevfs.c
changeset 569 3b366c606430
parent 0 68f95e015346
child 2621 4ea88858d952
--- a/usr/src/uts/common/fs/namefs/namevfs.c	Fri Sep 16 21:55:12 2005 -0700
+++ b/usr/src/uts/common/fs/namefs/namevfs.c	Sat Sep 17 09:54:49 2005 -0700
@@ -20,7 +20,7 @@
  * CDDL HEADER END
  */
 /*
- * Copyright 2004 Sun Microsystems, Inc.  All rights reserved.
+ * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
@@ -223,10 +223,10 @@
 		    (vfsp = NMTOV(nodep)->v_vfsp) != NULL && vfsp != &namevfs) {
 
 			/*
 			 * If the vn_vfslock fails, skip the vfs since
 			 * somebody else may be unmounting it.
 			 */
-			if (vn_vfslock(vfsp->vfs_vnodecovered)) {
+			if (vn_vfswlock(vfsp->vfs_vnodecovered)) {
 				realerr = EBUSY;
 				nodep = nodep->nm_nextp;
 				continue;
@@ -223,10 +223,10 @@
 
 			/*
-			 * If the vn_vfslock fails, skip the vfs since
+			 * If the vn_vfswlock fails, skip the vfs since
 			 * somebody else may be unmounting it.
 			 */